June 10, 2017, 11:50 (GMT) |
Draw Cache: fix probe vbo size |
Revision 0e1613d by Antonio Vazquez (experimental_gp_weight, greasepencil-experimental, greasepencil-object, greasepencil-refactor, soc-2019-npr, temp-gpencil-eval, temp-greasepencil-object-stacksplit, temp-greasepencil-vfx) June 10, 2017, 11:32 (GMT) |
New icons for Grease Pencil sculpt brushes In order to keep consistency, we have added icons to GP sculpt brushes similar to object sculpt |
June 10, 2017, 08:57 (GMT) |
fix for required shift when domains moves when domain moves away from position it was originally simulated it, a shift needs to be added to the particle coords. the was opposite to what is needed. |
June 10, 2017, 08:55 (GMT) |
set manta particle radius in particle system as well |
June 10, 2017, 08:45 (GMT) |
Cycles: Selectively include denoising in kernel |
June 10, 2017, 08:43 (GMT) |
corrected typo mistake in difference blend mode |
June 10, 2017, 08:08 (GMT) |
Cycles: Pass all buffers to each kernel call for OpenCL Technically not passing all buffers used by a kernel is undefined behavior. We haven't had any issues with this so far on AMD or Nvidia, but it's known to be a problem with Intel and we received a report from AMD that this is a problem on newer hardware, so we need to make this change at some point. Unfortunately there a cost to being correct, about 5% for the benchmark scenes. For low sample counts it's even worse, I've seen up to 50% slowdown. For the latter case I think adjusting tile updating logic can help, but not sure what that would look like yet (it would be just a few lines change however). |
June 10, 2017, 08:08 (GMT) |
Cycles: Faster split branched path tracing by sharing samples with inactive threads Unlike regular path tracing, branched path tracing is usually used with lower sample counts, at least for primary rays. This means that are less samples for the GPU to work on in parallel and rendering is slower. As there is less work overall there is also more inactive threads during rendering with BPT. This patch makes use of those inactive rays to render branched samples in parallel with other samples. Each thread that is preparing for a branched sample will attempt to find an inactive thread and if one is found the state for the sample is copied to that thread. Potentially, if there are enough inactive threads, 100s of branched samples could be generated from the same originating thread and ran in parallel giving large speed ups. Gives 70% faster render for pavillion midday scene. 20-60% faster on BMW with car paint replaced with SSS/volumes. |
June 10, 2017, 08:08 (GMT) |
Cycles: Modify path_radiance_accum_sample to use atomics for split kernel Samples ran in parallel need a safe way to accumulate their results with the results of other threads. |
June 10, 2017, 07:51 (GMT) |
Cycles: Add function to dequeue a ray |
June 10, 2017, 07:51 (GMT) |
Cycles: Add atomic decrement functions to util_atomic.h |
June 10, 2017, 07:51 (GMT) |
Cycles: Add kernel to enqueue inactive rays The queue will be used to make reuse of inactive threads to keep the GPU more busy. |
June 10, 2017, 07:51 (GMT) |
Cycles: Blacklist unsupported OpenCL devices Due to various driver issues with AMD GCN 1 cards we can no longer support these GPUs. This patch makes them unavailable to select for Cycles rendering. GCN cards 2 and higher are still supported. Please use the most recent drivers available to ensure proper functionality. See here for a list to check which GPUs are supported: https://en.wikipedia.org/wiki/List_of_AMD_graphics_processing_units |
June 10, 2017, 07:01 (GMT) |
Add a tab to user preferences Not sure if this is fully correct; getting crashes with non-factory settings. |
June 10, 2017, 05:33 (GMT) |
Merge branch '28' into custom-manipulators |
June 10, 2017, 00:59 (GMT) |
Rename node_widgets -> node_manipulators |
June 10, 2017, 00:59 (GMT) |
Missed last commit |
June 10, 2017, 00:42 (GMT) |
Manipulator Update/Refactor Sync with custom-manipulators branch - Use identifiers for properties. - Property array index access. - Remove operator from manipulators (wasn't used and will likely add in a different way). |
June 10, 2017, 00:20 (GMT) |
Cleanup: consistent naming Use shorter names for manipulator |
June 9, 2017, 23:18 (GMT) |
Merge branch '28' into custom-manipulators |
|
|
|


Master Commits
MiikaH:n Sivut a.k.a. MiikaHweb | 2003-2021